@@ -785,6 +785,10 @@ gdk_pixbuf__jpeg_image_begin_load (GdkPixbufModuleSizeFunc size_func,
 	JpegProgContext *context;
 	my_source_mgr   *src;
 
+	g_assert (size_func != NULL);
+	g_assert (prepared_func != NULL);
+	g_assert (updated_func != NULL);
+
 	context = g_new0 (JpegProgContext, 1);
 	context->size_func = size_func;
 	context->prepared_func = prepared_func;
@@ -949,13 +953,12 @@ gdk_pixbuf__jpeg_image_load_lines (JpegProgContext  *context,
                 context->dptr += (gsize)nlines * gdk_pixbuf_get_rowstride (context->pixbuf);
 
                 /* send updated signal */
-		if (context->updated_func)
-			(* context->updated_func) (context->pixbuf,
-						   0,
-						   cinfo->output_scanline - 1,
-						   cinfo->image_width,
-						   nlines,
-						   context->user_data);
+		(* context->updated_func) (context->pixbuf,
+					   0,
+					   cinfo->output_scanline - 1,
+					   cinfo->image_width,
+					   nlines,
+					   context->user_data);
         }
 
         return TRUE;
@@ -967,7 +970,7 @@ gdk_pixbuf__jpeg_image_load_lines (JpegProgContext  *context,
  * buf - new image data
  * size - length of new image data
  *
- * append image data onto inrecrementally built output image
+ * append image data onto incrementally built output image
  */
 static gboolean
 gdk_pixbuf__jpeg_image_load_increment (gpointer data,
@@ -1004,22 +1007,8 @@ gdk_pixbuf__jpeg_image_load_increment (gpointer data,
 		goto out;
 	}
 
-	/* skip over data if requested, handle unsigned int sizes cleanly */
-	/* only can happen if we've already called jpeg_get_header once   */
-	if (context->src_initialized && src->skip_next) {
-		if (src->skip_next > size) {
-			src->skip_next -= size;
-			retval = TRUE;
-			goto out;
-		} else {
-			num_left = size - src->skip_next;
-			bufhd = buf + src->skip_next;
-			src->skip_next = 0;
-		}
-	} else {
-		num_left = size;
-		bufhd = buf;
-	}
+	num_left = size;
+	bufhd = buf;
 
 	if (num_left == 0) {
 		retval = TRUE;
@@ -1031,6 +1020,19 @@ gdk_pixbuf__jpeg_image_load_increment (gpointer data,
 	spinguard = 0;
 	first = TRUE;
 	while (TRUE) {
+		/* skip over data if requested, handle unsigned int sizes cleanly */
+		/* only can happen if we've already called jpeg_get_header        */
+		if (context->src_initialized && src->skip_next) {
+			if (src->skip_next >= num_left) {
+				src->skip_next -= num_left;
+				retval = TRUE;
+				goto out;
+			} else {
+				num_left -= src->skip_next;
+				bufhd += src->skip_next;
+				src->skip_next = 0;
+			}
+		}
 
 		/* handle any data from caller we haven't processed yet */
 		if (num_left > 0) {
@@ -1090,16 +1092,14 @@ gdk_pixbuf__jpeg_image_load_increment (gpointer data,
 		
 			width = cinfo->image_width;
 			height = cinfo->image_height;
-			if (context->size_func) {
-				(* context->size_func) (&width, &height, context->user_data);
-				if (width == 0 || height == 0) {
-					g_set_error_literal (error,
-                                                             GDK_PIXBUF_ERROR,
-                                                             GDK_PIXBUF_ERROR_CORRUPT_IMAGE,
-                                                             _("Transformed JPEG has zero width or height."));
-					retval = FALSE;
-					goto out;
-				}
+			(* context->size_func) (&width, &height, context->user_data);
+			if (width == 0 || height == 0) {
+				g_set_error_literal (error,
+						     GDK_PIXBUF_ERROR,
+						     GDK_PIXBUF_ERROR_CORRUPT_IMAGE,
+						     _("Transformed JPEG has zero width or height."));
+				retval = FALSE;
+				goto out;
 			}
 			
 			cinfo->scale_num = 1;
@@ -1188,10 +1188,9 @@ gdk_pixbuf__jpeg_image_load_increment (gpointer data,
 			context->dptr = gdk_pixbuf_get_pixels (context->pixbuf);
 			
 			/* Notify the client that we are ready to go */
-			if (context->prepared_func)
-				(* context->prepared_func) (context->pixbuf,
-							    NULL,
-							    context->user_data);
+			(* context->prepared_func) (context->pixbuf,
+						    NULL,
+						    context->user_data);
 			
 		} else if (!context->did_prescan) {
 			int rc;			
